/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics;

import junit.framework.TestCase;

/**
 * <p>Unit test cases for ConfigurationException.</p>
 *
 * <p>This class is pretty simple. The test cases simply verifies the exception can be instantiated with the
 * error message and cause properly propagated, and that it comes with correct inheritance.</p>
 *
 * @author TCSDEVELOPER
 *
 * @version 1.0
 */
public class ConfigurationExceptionTests extends TestCase {

    /**
     * <p>The error message used for testing.</p>
     */
    private static final String ERROR_MESSAGE = "test error message";

    /**
     * <p>Creation test.</p>
     *
     * <p>Verifies the error message is properly propagated.</p>
     */
    public void testConfigurationException1() {
        ConfigurationException e = new ConfigurationException(ERROR_MESSAGE);

        assertNotNull("Unable to instantiate ConfigurationException.", e);
        assertEquals("Error message is not properly propagated to super class.",
                ERROR_MESSAGE, e.getMessage());
    }

    /**
     * <p>Creation test.</p>
     *
     * <p>Verifies the error message and the cause are properly propagated.</p>
     */
    public void testConfigurationException2() {
        Throwable cause = new Exception();
        ConfigurationException e = new ConfigurationException(ERROR_MESSAGE, cause);

        assertNotNull("Unable to instantiate ConfigurationException.", e);
        assertEquals("Cause is not properly propagated to super class.",
                cause, e.getCause());
    }

    /**
     * <p>Inheritance test.</p>
     *
     * <p>Verifies ConfigurationException subclasses BaseException.</p>
     */
    public void testConfigurationExceptionInheritance() {
        assertTrue("ConfigurationException does not subclass FileStatisticsException.",
                new ConfigurationException(ERROR_MESSAGE) instanceof FileStatisticsException);
    }

}
