/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics;

import junit.framework.TestCase;


/**
 * <p>
 * Unit test cases for Metric.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class MetricTests extends TestCase {
    /**
     * <p>
     * Verifies the constructor.
     * </p>
     */
    public void testMetric1() {
        assertNotNull("Unable to instantiate Metric.", new Metric("name", "display", "des"));
    }

    /**
     * <p>
     * Creates a Metric with null name. NullPointerException should be thrown.
     * </p>
     */
    public void testMetric2() {
        try {
            new Metric(null, "foo", "bar");
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Creates a Metric with null display name. NullPointerException should be thrown.
     * </p>
     */
    public void testMetric3() {
        try {
            new Metric("foo", null, "bar");
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Creates a Metric with null description. NullPointerException should be thrown.
     * </p>
     */
    public void testMetric4() {
        try {
            new Metric("foo", "bar", null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Creates a Metric with empty name. IllegalArgumentException should be thrown.
     * </p>
     */
    public void testMetric5() {
        try {
            new Metric(" ", "foo", "bar");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Creates a Metric with empty display name. IllegalArgumentException should be thrown.
     * </p>
     */
    public void testMetric6() {
        try {
            new Metric("foo", " ", "bar");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Creates a Metric with empty description. IllegalArgumentException should be thrown.
     * </p>
     */
    public void testMetric7() {
        try {
            new Metric("foo", "bar", " ");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the getName method.
     * </p>
     */
    public void testGetName() {
        assertEquals("The result should be name", "name", new Metric("name", "foo", "bar").getName());
    }

    /**
     * <p>
     * Tests the getDisplayName method.
     * </p>
     */
    public void testGetDisplayName() {
        assertEquals("The result should be display", "display",
            new Metric("foo", "display", "bar").getDisplayName());
    }

    /**
     * <p>
     * Tests the getDescription method.
     * </p>
     */
    public void testGetDescription() {
        assertEquals("The result should be des", "des",
            new Metric("foo", "bar", "des").getDescription());
    }

    /**
     * <p>
     * Tests the equals method.
     * </p>
     */
    public void testEquals1() {
        Metric metric = new Metric("foo", "bar", "bar");

        assertTrue("The result should be true", metric.equals(metric));
        assertTrue("The result should be true", metric.equals(new Metric("foo", "display", "des")));
    }

    /**
     * <p>
     * Tests the equals method.
     * </p>
     */
    public void testEquals2() {
        Metric metric = new Metric("foo", "bar", "bar");

        assertFalse("The result should be false", metric.equals(new Metric("bar", "display", "des")));
        assertFalse("The result should be false", metric.equals(null));
        assertFalse("The result should be false", metric.equals("foo"));
    }

    /**
     * <p>
     * Tests the hashCode method.
     * </p>
     */
    public void testHashCode() {
        assertEquals("the hash code should be same", "foo".hashCode(),
            new Metric("foo", "bar", "des").hashCode());
    }
}
