/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.util.config.Property;


/**
 * <p>
 * FileCategoryMatcher concrete implementation that matches binary files.
 * </p>
 *
 * <p>
 * Configuration: Constructor with Property is provided to address reflection contract with no real
 * use.
 * </p>
 *
 * <p>
 * Thread Safety: This class is stateless and thread-safe.
 * </p>
 *
 * @author WishingBone, TCSDEVELOPER
 * @version 1.0
 */
public class BinaryFileMatcher extends FileCategoryMatcher {
    /**
     * <p>
     * Creates a BinaryFileMatcher instance.
     * </p>
     */
    public BinaryFileMatcher() {
        // empty
    }

    /**
     * <p>
     * Creates a BinaryFileMatcher instance with given property. Note: This Constractor is provided
     * to address reflection contract with no real use.
     * </p>
     *
     * @param property the property to configure from
     *
     * @throws NullPointerException if property is null
     */
    public BinaryFileMatcher(Property property) {
        MatcherHelper.checkNull(property, "property");
    }

    /**
     * <p>
     * Return whether file is binary.
     * </p>
     *
     * @param isBinary whether file is binary
     *
     * @return whether file is binary
     */
    protected boolean match(boolean isBinary) {
        return isBinary;
    }
}
