/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics;

import junit.framework.TestCase;

/**
 * <p>Unit test cases for FileStatisticsException.</p>
 *
 * <p>This class is pretty simple. The test cases simply verifies the exception can be instantiated with the
 * error message and cause properly propagated, and that it comes with correct inheritance.</p>
 *
 * @author TCSDEVELOPER
 *
 * @version 1.0
 */
public class FileStatisticsExceptionTests extends TestCase {

    /**
     * <p>The error message used for testing.</p>
     */
    private static final String ERROR_MESSAGE = "test error message";

    /**
     * <p>Creation test.</p>
     *
     * <p>Verifies the error message is properly propagated.</p>
     */
    public void testFileStatisticsException1() {
        FileStatisticsException e = new FileStatisticsException(ERROR_MESSAGE);

        assertNotNull("Unable to instantiate FileStatisticsException.", e);
        assertEquals("Error message is not properly propagated to super class.",
                ERROR_MESSAGE, e.getMessage());
    }

    /**
     * <p>Creation test.</p>
     *
     * <p>Verifies the error message and the cause are properly propagated.</p>
     */
    public void testFileStatisticsException2() {
        Throwable cause = new Exception();
        FileStatisticsException e = new FileStatisticsException(ERROR_MESSAGE, cause);

        assertNotNull("Unable to instantiate FileStatisticsException.", e);
        assertEquals("Cause is not properly propagated to super class.",
                cause, e.getCause());
    }

    /**
     * <p>Inheritance test.</p>
     *
     * <p>Verifies FileStatisticsException subclasses BaseException.</p>
     */
    public void testFileStatisticsExceptionInheritance() {
        assertTrue("FileStatisticsException does not subclass Exception.",
                new FileStatisticsException(ERROR_MESSAGE) instanceof Exception);
    }

}
