/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics;

import junit.framework.TestCase;
import java.io.File;


/**
 * <p>
 * Unit test cases for Main.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class MainTests extends TestCase {
    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files";

    /**
     * The namespace for this test.
     */
    private static final String NAMESPACE = "com.topcoder.file.statistics.unittest";

    /**
     * The default namespace.
     */
    private static final String DEFAULT_NAMESPACE = "com.topcoder.file.statistics.Main";

    /**
     * The namespace for Magic Numbers component.
     */
    private static final String MAGIC_NUMBERS_NAMESPACE = "com.topcoder.file.mime.MagicNumbers.xml";

    /**
     * Remove the configuration after testing.
     *
     * @throws Exception to JUnit
     */
    protected void tearDown() throws Exception {
        TestHelper.removeNamespace(NAMESPACE);
        TestHelper.removeNamespace(DEFAULT_NAMESPACE);
        TestHelper.removeNamespace(MAGIC_NUMBERS_NAMESPACE);
    }

    /**
     * <p>
     * Tests main method with recursive feature..
     * </p>
     */
    public void testMain1() {
        String[] args = new String[] {
            "-c", "main_config1.xml", "-n", NAMESPACE, "-b", BASE_PATH, "-r", "\\dir"
        };
        System.out.print("*** testMain1 assertion: ");
        System.out.println("A report about 'dir' should follow. Subdirectory is included.");
        Main.main(args);
        System.out.println("*** End testMain1");
    }

    /**
     * <p>
     * Tests main method without recursive feature.
     * </p>
     */
    public void testMain2() {
        String[] args = new String[] {
            "-c", "main_config1.xml", "-n", NAMESPACE, "-b", BASE_PATH, "\\dir"
        };
        System.out.print("*** testMain2 assertion: ");
        System.out.println("A report about 'dir' should follow. Subdirectory is not included.");
        Main.main(args);
        System.out.println("*** End testMain2");
    }

    /**
     * <p>
     * Tests main method with multiple paths.
     * </p>
     */
    public void testMain3() {
        String[] args = new String[] {
            "-c", "main_config2.xml", "-b", BASE_PATH, "\\dir", "\\test.txt"
        };
        System.out.print("*** testMain3 assertion: ");
        System.out.println("A report about 'dir' and 'test.txt' should follow.");
        Main.main(args);
        System.out.println("*** End testMain3");
    }

    /**
     * <p>
     * Tests main method without config file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMain4() throws Exception {
        TestHelper.loadConfigFile("config5.xml", DEFAULT_NAMESPACE);

        String[] args = new String[] {BASE_PATH + "\\dir"};
        System.out.print("*** testMain4 assertion: ");
        System.out.println("A report about 'dir' should follow. Absolute path is used.");
        Main.main(args);
        System.out.println("*** End testMain4");
    }

    /**
     * <p>
     * Tests main method with invalid arguments.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMain5() throws Exception {
        System.out.print("*** testMain5 assertion: ");
        System.out.println("Help message should follow.");
        Main.main(new String[0]);
        System.out.println("*** End testMain5");
    }

    /**
     * <p>
     * Tests main method with invalid arguments.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMain6() throws Exception {
        System.out.print("*** testMain6 assertion: ");
        System.out.println("Help message should follow.");
        Main.main(new String[] {"-o", "o1", "o2", "-r", "file"});
        System.out.println("*** End testMain6");
    }

    /**
     * <p>
     * Tests main method with invalid arguments.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMain7() throws Exception {
        System.out.print("*** testMain7 assertion: ");
        System.out.println("Help message should follow.");
        Main.main(new String[] {"-o", "o1", "-r", "-n", "n"});
        System.out.println("*** End testMain7");
    }

    /**
     * <p>
     * Tests main method with invalid config file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMain8() throws Exception {
        System.out.print("*** testMain8 assertion: ");
        System.out.println("Error message about config file should follow.");
        Main.main(new String[] {"-c", "no_this_file", "path"});
        System.out.println("*** End testMain8");
    }

    /**
     * <p>
     * Tests main method with invalid namespace.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMain9() throws Exception {
        System.out.print("*** testMain9 assertion: ");
        System.out.println("Error message about namespace should follow.");
        Main.main(new String[] {"-n", "no_this_namespace", "path"});
        System.out.println("*** End testMain9");
    }

    /**
     * <p>
     * Tests main method with invalid namespace.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testMain10() throws Exception {
        System.out.print("*** testMain10 assertion: ");
        System.out.println("Error message about base directory should follow.");
        Main.main(new String[] {"-c", "main_config2.xml", "-b", "no_this_path", "path"});
        System.out.println("*** End testMain10");
    }

    /**
     * <p>
     * Tests main method with invalid config file.
     * </p>
     */
    public void testMain11() {
        String[] args = new String[] {
            "-c", "main_invalid.xml", "-n", NAMESPACE, "-b", BASE_PATH, "-r",
            BASE_PATH + "\\dir",
        };
        System.out.print("*** testMain11 assertion: ");
        System.out.println("Error message about creating ExtendedFileStatistics should follow.");
        Main.main(args);
        System.out.println("*** End testMain11");
    }

    /**
     * <p>
     * Tests main method with invalid config file.
     * </p>
     */
    public void testMain12() {
        String[] args = new String[] {
            "-c", "main_config1.xml", "-n", NAMESPACE, "-b", BASE_PATH, "-r", "\\no_such_file",
        };
        System.out.print("*** testMain12 assertion: ");
        System.out.println("Error message about invalid file should follow.");
        Main.main(args);
        System.out.println("*** End testMain12");
    }

    /**
     * <p>
     * Tests main method with given output file.
     * </p>
     */
    public void testMain13() {
        String[] args = new String[] {
            "-c", "main_config1.xml", "-n", NAMESPACE, "-b", BASE_PATH, "-r", "-o",
            "\\output", "\\dir",
        };
        Main.main(args);

        File output = new File(BASE_PATH, "output");
        assertTrue("output should be created", output.isFile());
        output.delete();
    }

    /**
     * <p>
     * Tests main method with xslt.
     * </p>
     */
    public void testMain14() {
        String[] args = new String[] {
            "-c", "main_config3.xml", "-n", NAMESPACE, "-b", BASE_PATH, "-r", "\\dir",
        };

        System.out.print("*** testMain14 assertion: ");
        System.out.println("A transformed report should follow.");
        Main.main(args);
        System.out.println("*** End testMain14");
    }

    /**
     * <p>
     * Tests main method with magic numbers component.
     * </p>
     */
    public void testMain15() {
        String[] args = new String[] {
            "-c", "main_config4.xml", "-b", BASE_PATH, "-r", "\\dir1",
        };

        System.out.print("*** testMain15 assertion: ");
        System.out.println("A report about 'dir1' should follow.");
        Main.main(args);
        System.out.println("*** End testMain15");
    }
}
