/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests;

import java.io.File;

import junit.framework.TestCase;

import com.topcoder.file.statistics.ExtendedFileStatistics;
import com.topcoder.file.statistics.FileProcessor;
import com.topcoder.file.statistics.reporting.XmlStatsReporting;


/**
 * <p>
 * Unit test cases for FileStatistics
 * </p>
 *
 * @author cucu
 * @version 1.0
 */
public class ExtendedFileStatisticsAccuracyTests extends TestCase {

    /**
     * Object to be tested
     */
    private ExtendedFileStatistics efs;

    /**
     * Set up for each test.
     */
    public void setUp() throws Exception  {
        TestHelper.unloadNamespace(TestHelper.FILE_STATISTICS_NAMESPACE);
        TestHelper.loadConfig(TestHelper.FILE_STATISTICS_CONFIG);
        efs = new ExtendedFileStatistics(TestHelper.FILE_STATISTICS_NAMESPACE);
    }

    /**
     * Tear down for each test.
     */
    public void tearDown() throws Exception  {
        TestHelper.unloadNamespace(TestHelper.FILE_STATISTICS_NAMESPACE);
    }

    /**
     * test the ProcessDirectory method (non recursive)
     */
    public void testProcessDirectory() throws Exception {
        efs.processDirectory(new File("test_files/AccuracyTests/files"));

        // Save to a file for visual inspection
        TestHelper.saveToFile("FileStatisticsResults/Extended1.xml", efs.getReporting().generateReport());
    }

    /**
     * test the ProcessDirectory method (recursive)
     */
    public void testProcessDirectoryRecursive() throws Exception {

        efs.processDirectory(new File("test_files/AccuracyTests/files"), true);

        // Save to a file for visual inspection
        TestHelper.saveToFile("FileStatisticsResults/Extended2.xml", efs.getReporting().generateReport());
    }

    /**
     * Test PrintReport to the console
     */
    public void testPrintReport() throws Exception {
        efs.processDirectory(new File("test_files/AccuracyTests/files"));
        System.out.println("------ PrintReport result ------");
        efs.printReport();
        System.out.println("------ End of PrintReport result ------");
    }


    /**
     *  Test PrintReport to a file
     */
    public void testPrintReportToFile() throws Exception {
        efs.processDirectory(new File("test_files/AccuracyTests/files"));
        efs.printReport(new File("test_files/AccuracyTests/FileStatisticsResults/Extended3.xml"));
    }

}
