/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests;

import java.io.FileOutputStream;
import java.io.PrintStream;

import junit.framework.TestCase;

import com.topcoder.file.statistics.Main;


/**
 * <p>
 * Unit test cases for Main
 * </p>
 *
 * @author cucu
 * @version 1.0
 */
public class MainAccuracyTests extends TestCase {

    /**
     * Test running without parameters
     */
    public void testWithoutParam()  throws Exception {

        run(new String[] {}, "withoutParams.txt");
    }

    /**
     * Test running with just a file
     */
    public void test1() throws Exception {

        run(new String[] {"-c",  TestHelper.FILE_STATISTICS_MAIN_CONFIG,
                          "-n",  TestHelper.FILE_STATISTICS_NAMESPACE,
                            TestHelper.TXT_FILE}, "result1.txt");
    }

    /**
     *  Test running with a file using a base directory and two files
     */
    public void test2() throws Exception {

       run(new String[] {"-c", TestHelper.FILE_STATISTICS_MAIN_CONFIG,
                             "-n", TestHelper.FILE_STATISTICS_NAMESPACE,
                             "-b", "test_files/AccuracyTests/files/",
                             "textFile1.txt",
                             "lyric.txt"}, "result2.txt");
    }

    /**
     * Test running with a directory but not recursive
     */
    public void test3() throws Exception {

        run(new String[] {"-c",  TestHelper.FILE_STATISTICS_MAIN_CONFIG,
                             "-n", TestHelper.FILE_STATISTICS_NAMESPACE,
                             "test_files/AccuracyTests/files/"}, "result3.txt");
    }

    /**
     * Test running with a directory recursive
     */
    public void test4() throws Exception {

        run(new String[] {"-c", TestHelper.FILE_STATISTICS_MAIN_CONFIG,
                             "-n", TestHelper.FILE_STATISTICS_NAMESPACE,
                             "-r",
                             "test_files/AccuracyTests/files/"}, "result4.txt");

    }

    /**
     * Test running with a directory recursive
     */
    public void test5() throws Exception {
        run(new String[] {"-c", TestHelper.FILE_STATISTICS_MAIN_CONFIG,
                             "-n", TestHelper.FILE_STATISTICS_NAMESPACE,
                             "-o", "test_files/AccuracyTests/CommandLineResults/result5.out",
                             TestHelper.TXT_FILE}, "result5.txt");
    }

    /**
     *  Run from the command line, redirecting the output to the specified filename
     * @param parameters Parameters used to call the command line
     * @param file to save the output
     */
    private void run(String []parameters, String filename) throws Exception {
        TestHelper.unloadNamespace(TestHelper.FILE_STATISTICS_NAMESPACE);

        String descr = "Running application with parameters: ";
        for (int i = 0; i < parameters.length; i++) {
            descr = descr + " " + parameters[i];
        }

        PrintStream previous = System.out;
        try {
            PrintStream ps = new PrintStream(
            		new FileOutputStream("test_files/AccuracyTests/CommandLineResults/" + filename));
            System.setOut(ps);

            System.out.println(descr);

            Main.main(parameters);
            ps.close();
        }  finally {
            System.setOut(previous);
        }

    }

}
