/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved
 */
package com.topcoder.file.statistics.accuracytests;

import java.io.BufferedWriter;
import java.io.FileWriter;

import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.ConfigManagerException;

/**
 * Helper methods and constants for accuracy tests.
 *
 * @author cucu
 */
public class TestHelper {


    /**
     * File Statistics namesapce 
     */
	public final static String FILE_STATISTICS_NAMESPACE = "com.topcoder.file.statistics";

    /**
     * Name of the configuration file used for testing File Statisticas 
     */
    public final static String FILE_STATISTICS_CONFIG = "AccuracyTests/FileStatistics.xml";

    /**
     * Name of the configuration file used for testing Main class 
     */
    public final static String FILE_STATISTICS_MAIN_CONFIG = "AccuracyTests/FileStatisticsMain.xml";

    /**
     * Name of the configuration file used for tests of matchers.
     */
    public final static String MATCHERS_CONFIG = "AccuracyTests/Matchers.xml";

    /**
     * Matchers namespace
     */
    public final static String MATCHER_NAMESPACE = "com.topcoder.file.statistics.matcher";

    /**
     * Configuration file for Magic Numbers component
     */
    public final static String MAGIC_NUMBERS_CONFIG = "AccuracyTests/MagicNumber.xml";

    /**
     * Magic Numbers namespace  
     */
    public static final String MAGIC_NUMBERS_NAMESPACE = "com.topcoder.file.type.MagicNumbers.xml";

    /**
     * Processors namespace
     */
    public static final String PROCESSOR_NAMESPACE = "com.topcoder.file.statistics.processors";

    /**
     * Configuration file for processors
     */
    public static final String PROCESSOR_CONFIG = "AccuracyTests/Processor.xml";

    /**
     *  Name of a txt file used for matching
     */
    public final static String TXT_FILE = "test_files/AccuracyTests/files/textFile1.txt";

    /**
     * Name of a txt file used for line counting
     */
    public final static String LYRIC_TXT_FILE = "test_files/AccuracyTests/files/lyric.txt";

    /**
     * Name of a txt file used for line counting
     */
    public final static String BIG_TXT_FILE = "test_files/AccuracyTests/files/bigfile.txt";
    
    /**
     * Name of a cs file used for matching and C Style line counting
     */
    public final static String CS_FILE = "test_files/AccuracyTests/files/program.cs";

    /**
     * Name of a java file used for C Style line counting
     */
    public final static String JAVA_FILE = "test_files/AccuracyTests/files/HelloWorld.java";

    /**
     * Name of a cpp file used for C Style line counting
     */
    public final static String CPP_FILE = "test_files/AccuracyTests/files/AlphabetCount.cpp";

    /**
     *  Name of a cpp file used for C Style line counting
     */
    public final static String CPP_FILE_ANOTHER_DIR = "test_files/AccuracyTests/files/another_dir/AlphabetCount.cpp";
    
    /**
     *  Name of a zip file used for matching
     */
    public final static String ZIP_FILE = "test_files/AccuracyTests/files/binaryFile1.zip";

   
    /**
     *  Name of a dll file used for matching
     */
    public final static String DLL_FILE = "test_files/AccuracyTests/files/binaryFile2.dll";

    /**
     * Load a file in config manager
     * @param filename name of the file
     * @throws ConfigManagerException
     */
    public static void loadConfig(String filename) throws ConfigManagerException {
        ConfigManager.getInstance().add(filename);
    }

    /**
     * Take off the namespace from config manager
     * @param namespace name of the file
     * @throws ConfigManagerException
     */
    public static void unloadNamespace(String namespace) throws ConfigManagerException {
        ConfigManager cm = ConfigManager.getInstance();
        if (cm.existsNamespace(namespace)) {
            cm.removeNamespace(namespace);
        }
    }
    
    /**
     * Save a string to a file
     * @param filename name of the file
     * @param str string to save
     * @throws Exception
     */
    public static void saveToFile(String filename, String str) throws Exception {
        BufferedWriter out = new BufferedWriter(new FileWriter("test_files/AccuracyTests/" + filename));
        out.write(str);
        out.close();

    }


}
