/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests.processor.linecounter;

import java.io.File;

import junit.framework.TestCase;

import com.topcoder.file.statistics.FileProcessor;
import com.topcoder.file.statistics.Metric;
import com.topcoder.file.statistics.accuracytests.TestHelper;
import com.topcoder.file.statistics.matcher.AnyFileMatcher;
import com.topcoder.file.statistics.processor.linecounter.CStyleLineCounter;


/**
 * <p>
 * Accuracy tests for CStyleLineCounter
 * </p>
 *
 * @author cucu
 * @version 1.0
 */
public class CStyleLineCounterAccuracyTests extends TestCase {

    /**
     *  Test the line count against some files.
     */
    public void testTextLineCount() throws Exception {
        FileProcessor fp = new CStyleLineCounter("txt", new AnyFileMatcher());

        verifyLineCount(fp, TestHelper.CS_FILE, 3);
        verifyLineCount(fp, TestHelper.JAVA_FILE, 9);
        verifyLineCount(fp, TestHelper.CPP_FILE, 36);

    }

    /**
     * Verifies that the line count is correct for a file
     * 
     * @param fp FileProcessor that will process the file
     * @param filename  file whose text lines will be counted
     * @param expectedCount expected number of lines
     */
    private void verifyLineCount(FileProcessor fp, String filename, long expectedCount) throws Exception  {
        assertEquals(" bad C Style line count for "  + filename, expectedCount,
                fp.process(new File(filename)).getStat((Metric) fp.getSupportedMetrics().get(0)));

    }

}
