/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests.reporting;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;

import junit.framework.TestCase;

import com.topcoder.file.statistics.FileProcessor;
import com.topcoder.file.statistics.StatsResult;
import com.topcoder.file.statistics.accuracytests.TestHelper;
import com.topcoder.file.statistics.matcher.AnyFileMatcher;
import com.topcoder.file.statistics.processor.linecounter.CStyleLineCounter;
import com.topcoder.file.statistics.reporting.BasicStatsReporting;


/**
 * <p>
 * Accuracy tests for BasicStatsReporting
 * </p>
 *
 * @author cucu
 * @version 1.0
 */
public class BasicStatsReportingAccuracyTests extends TestCase {

    /**
     *  Test creating an empty report and saving it so it can be visually inspected.
     */
    public void testEmptyReport() throws Exception {
        BasicStatsReporting bsr = new BasicStatsReporting();
        createReport(bsr, new String[]{}, "test_files/AccuracyTests/ReportResults/EmptyReport.txt");
    }

    /**
     * Test creating a report of a file and saving it so it can be visually inspected.
     */
    public void testReport1() throws Exception {
        BasicStatsReporting bsr = new BasicStatsReporting();
        createReport(bsr, new String[]{TestHelper.CS_FILE}, "test_files/AccuracyTests/ReportResults/Report1.txt");
    }

    /**
     * Test creating a report of some files and saving it so it can be visually inspected.
     */
    public void testReport2() throws Exception {
        BasicStatsReporting bsr = new BasicStatsReporting();
        createReport(bsr, new String[]{TestHelper.CS_FILE, TestHelper.JAVA_FILE, TestHelper.CPP_FILE, TestHelper.CPP_FILE_ANOTHER_DIR}
                , "test_files/AccuracyTests/ReportResults/Report2.txt");
    }

    /**
     * Test doing a reset to have a base directory.
     */
    public void testReset() throws Exception {
        BasicStatsReporting bsr = new BasicStatsReporting();
        bsr.reset(new File("test_files/AccuracyTests/files/"));

        createReport(bsr, new String[]{TestHelper.CS_FILE, TestHelper.JAVA_FILE, TestHelper.CPP_FILE, TestHelper.CPP_FILE_ANOTHER_DIR},
            "test_files/AccuracyTests/ReportResults/Reset.txt");
    }


    /**
     * Creata a report with BasicStatsReporting and outputs it to a file
     * 
     * @param bsr BasicStatsReporting to generate
     * @param files files to be processed
     * @param outputFileName name of the file where the report is written
     * @throws Exception
     */
    private void createReport(BasicStatsReporting bsr, String []files, String outputFileName) throws Exception {

        FileProcessor fp = new CStyleLineCounter("Source File", new AnyFileMatcher());

        for (int i = 0; i < files.length; i++)   {

            StatsResult sr = new StatsResult();
            File fi = new File(files[i]);
            sr.aggregate(fp.process(fi));
            bsr.aggregate(fp, fi.getAbsolutePath(), sr);
        }
        BufferedWriter out = new BufferedWriter(new FileWriter(outputFileName));
        out.write(bsr.generateReport());
        out.close();
    }
    

}
