/*
 * $(#)StatsResultTests.java		Sep 6, 2005
 * 
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests;

import junit.framework.TestCase;

import com.topcoder.file.statistics.Metric;
import com.topcoder.file.statistics.StatsResult;

/**
 * This test case contains the failure tests for the <code>StatsResult</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class StatsResultTests extends TestCase {

    /**
     * A StatsResult instance to test.
     */
    private StatsResult result = null;
    
    /**
     * Creates an empty StatsResult instance.
     */
    protected void setUp() {
        result = new StatsResult();
    }
    
    /**
     * Checks whether the constructor StatsResult(StatsResult) properly throws
     * NullPointerException for null argument.
     */
    public void testStatsResult() {
        try {
            new StatsResult(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }
    
    /**
     * Checks whether the method setStat(Metric, long) properly throws
     * NullPointerException for null argument.
     */
    public void testSetStat() {
        try {
            result.setStat(null, 1);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }
    
    /**
     * Checks whether the method getStat(Metric) properly throws
     * NullPointerException for null argument.
     */
    public void testGetStat1() {
        try {
            result.getStat(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }
    
    /**
     * Checks whether the method getStat(Metric) properly throws
     * IllegalArgumentException for invalid argument.
     */
    public void testGetStat2() {
        try {
            result.getStat(new Metric("metric", "metric", "A metric"));
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }
    
    /**
     * Checks whether the method getStat(Metric) properly throws
     * NullPointerException for null argument.
     */
    public void testAggregate() {
        try {
            result.aggregate(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }
}
