/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.matcher;

import junit.framework.TestCase;
import java.io.File;
import java.io.IOException;

/**
 * <p>
 * Unit test cases for FileCategoryMatcher.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class FileCategoryMatcherTests extends TestCase {

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files/matcher/";

    /**
     * <p>
     * Tests the isBinary method with null argument. NullPointerException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary1() throws Exception {
        try {
            FileCategoryMatcher.isBinary((File) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the isBinary method with invalid File. IOException should be thrown.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary2() throws Exception {
        try {
            FileCategoryMatcher.isBinary(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary3() throws Exception {
        assertFalse("The result should be false", FileCategoryMatcher.isBinary(new File(BASE_PATH, "test1.txt")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a text file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary4() throws Exception {
        assertFalse("The result should be false", FileCategoryMatcher.isBinary(new File(BASE_PATH, "test2.txt")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary5() throws Exception {
        assertTrue("The result should be true", FileCategoryMatcher.isBinary(new File(BASE_PATH, "test1.bin")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates a binary file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary6() throws Exception {
        assertTrue("The result should be true", FileCategoryMatcher.isBinary(new File(BASE_PATH, "test2.bin")));
    }

    /**
     * <p>
     * Tests the isBinary method. Validates an empty file.
     * </p>
     *
     * @throws Exception to JUnit
     */
    public void testIsBinary7() throws Exception {
        assertFalse("The result should be false", FileCategoryMatcher.isBinary(new File(BASE_PATH, "empty")));
    }

}
